@@ -186,6 +186,21 @@ class AlgorithmContainerConfigParser:
             print('[Step 6 Error, Deployment compose file Generated Failed]: ' + err_msg)
             traceback.print_exc()
 
+    def generate_local_start_script(self):
+        try:
+            with open(os.path.join(self.cur_dir, 'algorithm-local-start.template'), 'r') as f:
+                templates = f.read()
+            templates.replace("{ALGORITHM_NAME}", self.algorithm_name)
+            templates.replace("{ALGORITHM_VERSION}", self.algorithm_version)
+            with open(os.path.join(self.service_dir, 'vsource_local_start.sh'), 'w') as f:
+                f.write(templates)
+            print('[Step Local] Local start script has been successfully generated!')
+
+        except Exception as e:
+            err_msg = traceback.format_exc()
+            print('[Step Local Error, Local start script file Generated Failed]: ' + err_msg)
+            traceback.print_exc()
+
     def generate(self):
         self.gen_requirements_txt()
         self.gen_dockerfile()
@@ -194,6 +209,8 @@ class AlgorithmContainerConfigParser:
         self.gen_deployment_compose()
         self.gen_control_script()
 
+        self.generate_local_start_script()
+
 def parse_algorithm(config):
     a = AlgorithmContainerConfigParser(config)
     a.generate()
